==> nautilus-actions-3.0.3.tar.gz: nautilus-actions-3.0.3/src/nact/base-keysyms.h <==
/*
 * Nautilus Actions
 * A Nautilus extension which offers configurable context menu actions.
 *
 * Copyright (C) 2005 The GNOME Foundation
 * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
 * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
 *
 * This Program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This Program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this Library; see the file COPYING.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors:
 *   Frederic Ruaudel <grumz@grumz.net>
 *   Rodrigo Moya <rodrigo@gnome-db.org>
 *   Pierre Wieser <pwieser@trychlos.org>
 *   ... and many others (see AUTHORS)
 */

#ifndef __BASE_KEYSYMS_H__
#define __BASE_KEYSYMS_H__

/**
 * SECTION: base_window
 * @short_description: #BaseWindow public function declaration.
 * @include: nact/base-window.h
 *
 * This is a base class which encapsulates a Gtk+ windows.
 * It works together with the BaseApplication class to run a Gtk+
 * application.
 */

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

G_BEGIN_DECLS

/* GDK_KEY_ defines have been defined since Gtk+ 2.21.8
 */
#if(( GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 22 ) || GTK_MAJOR_VERSION >= 3 )

#define NACT_KEY_Escape    (GDK_KEY_Escape)
#define NACT_KEY_Insert    (GDK_KEY_Insert)
#define NACT_KEY_Delete    (GDK_KEY_Delete)
#define NACT_KEY_Return    (GDK_KEY_Return)
#define NACT_KEY_KP_Delete (GDK_KEY_KP_Delete)
#define NACT_KEY_KP_Enter  (GDK_KEY_KP_Enter)
#define NACT_KEY_KP_Insert (GDK_KEY_KP_Insert)
#define NACT_KEY_Left      (GDK_KEY_Left)
#define NACT_KEY_Right     (GDK_KEY_Right)
#define NACT_KEY_F2        (GDK_KEY_F2)

#else

#define NACT_KEY_Escape    (GDK_Escape)
#define NACT_KEY_Insert    (GDK_Insert)
#define NACT_KEY_Delete    (GDK_Delete)
#define NACT_KEY_Return    (GDK_Return)
#define NACT_KEY_KP_Delete (GDK_KP_Delete)
#define NACT_KEY_KP_Enter  (GDK_KP_Enter)
#define NACT_KEY_KP_Insert (GDK_KP_Insert)
#define NACT_KEY_Left      (GDK_Left)
#define NACT_KEY_Right     (GDK_Right)
#define NACT_KEY_F2        (GDK_F2)

#endif

G_END_DECLS

#endif /* __BASE_KEYSYMS_H__ */

==> nautilus-actions-3.1.2.tar.gz: nautilus-actions-3.1.2/src/nact/base-keysyms.h <==
/*
 * Nautilus-Actions
 * A Nautilus extension which offers configurable context menu actions.
 *
 * Copyright (C) 2005 The GNOME Foundation
 * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
 * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
 *
 * This Program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This Program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this Library; see the file COPYING.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA 02111-1307, USA.
 *
 * Authors:
 *   Frederic Ruaudel <grumz@grumz.net>
 *   Rodrigo Moya <rodrigo@gnome-db.org>
 *   Pierre Wieser <pwieser@trychlos.org>
 *   ... and many others (see AUTHORS)
 */

#ifndef __BASE_KEYSYMS_H__
#define __BASE_KEYSYMS_H__

/**
 * SECTION: base_window
 * @short_description: #BaseWindow public function declaration.
 * @include: nact/base-window.h
 *
 * This is a base class which encapsulates a Gtk+ windows.
 * It works together with the BaseApplication class to run a Gtk+
 * application.
 */

#include <gtk/gtk.h>
#include <gdk/gdkkeysyms.h>

G_BEGIN_DECLS

/* GDK_KEY_ defines have been defined since Gtk+ 2.21.8 released on 2010-09-14
 * see http://git.gnome.org/browse/gtk+/commit/?id=750c81f43dda6c783372b983e630ecd30b776d7e
 */
#if GTK_CHECK_VERSION( 2, 21, 8 )

#define NACT_KEY_Escape    (GDK_KEY_Escape)
#define NACT_KEY_Insert    (GDK_KEY_Insert)
#define NACT_KEY_Delete    (GDK_KEY_Delete)
#define NACT_KEY_Return    (GDK_KEY_Return)
#define NACT_KEY_KP_Delete (GDK_KEY_KP_Delete)
#define NACT_KEY_KP_Enter  (GDK_KEY_KP_Enter)
#define NACT_KEY_KP_Insert (GDK_KEY_KP_Insert)
#define NACT_KEY_Left      (GDK_KEY_Left)
#define NACT_KEY_Right     (GDK_KEY_Right)
#define NACT_KEY_F2        (GDK_KEY_F2)

#else

#define NACT_KEY_Escape    (GDK_Escape)
#define NACT_KEY_Insert    (GDK_Insert)
#define NACT_KEY_Delete    (GDK_Delete)
#define NACT_KEY_Return    (GDK_Return)
#define NACT_KEY_KP_Delete (GDK_KP_Delete)
#define NACT_KEY_KP_Enter  (GDK_KP_Enter)
#define NACT_KEY_KP_Insert (GDK_KP_Insert)
#define NACT_KEY_Left      (GDK_Left)
#define NACT_KEY_Right     (GDK_Right)
#define NACT_KEY_F2        (GDK_F2)

#endif

G_END_DECLS

#endif /* __BASE_KEYSYMS_H__ */
